## ----global_options, include=FALSE---------------------------------------
library(knitr)
knitr::opts_chunk$set(dpi = 100, echo= TRUE, warning=FALSE, message=FALSE, fig.align = 'center', 
                      fig.show=TRUE, fig.keep = 'all', out.width = '50%') 

## ----message = TRUE------------------------------------------------------
library(mixOmics)

## ------------------------------------------------------------------------
data(srbct)
#the gene expression data
X = srbct$gene  
dim(X)
# the tumour subtypes
summary(srbct$class)

## ------------------------------------------------------------------------
pca.srbct = pca(X, ncomp = 10, center = TRUE, scale = TRUE)
#pca.srbct #outputs the explained variance per component
plot(pca.srbct)  # screeplot of the eingenvalues (explained variance per component)

## ------------------------------------------------------------------------
plotIndiv(pca.srbct, ind.names = FALSE, pch = 16, title = 'PCA on SRBCT')

## ------------------------------------------------------------------------
plotIndiv(pca.srbct, group = srbct$class, ind.names = FALSE, 
          legend = TRUE, title = 'PCA on SRBCT')

## ------------------------------------------------------------------------
Y = srbct$class 
summary(Y)        #outcome categories

## ------------------------------------------------------------------------
srbct.plsda <- plsda(X, Y, ncomp = 5)  # set ncomp to 5 for performance assessment later
plotIndiv(srbct.plsda , comp = 1:2,
          group = srbct$class, ind.names = FALSE, 
          ellipse = TRUE, legend = TRUE, title = 'PLSDA on SRBCT')

## ------------------------------------------------------------------------
# with background
# ~ takes 30 sec to run the simulations
background = background.predict(srbct.plsda, comp.predicted=  2, dist = "max.dist") 

plotIndiv(srbct.plsda, comp = 1:2,
          group = srbct$class, ind.names = FALSE, title = "Maximum distance",
          legend = TRUE,  background = background)

## ------------------------------------------------------------------------
# takes a~ 1 minute to run
set.seed(2543) # for reproducibility, only when the `cpus' argument is not used
perf.plsda.srbct <- perf(srbct.plsda, validation = "Mfold", folds = 5, 
                  progressBar = FALSE, auc = TRUE, nrepeat = 10) 

## ------------------------------------------------------------------------
# perf.plsda.srbct$error.rate  # error rates
plot(perf.plsda.srbct, col = color.mixo(5:7), sd = TRUE, legend.position = "horizontal")

## ------------------------------------------------------------------------
auc.plsda = auroc(srbct.plsda, roc.comp = 6)

## ----include = TRUE------------------------------------------------------
load('RData/result-SRBCT-sPLSDA.Rdata')

## ------------------------------------------------------------------------
ncomp <- tune.splsda.srbct$choice.ncomp$ncomp # optimal number of components based on t-tests
ncomp

## ------------------------------------------------------------------------
select.keepX <- tune.splsda.srbct$choice.keepX[1:ncomp]  # optimal number of variables to select
select.keepX

## ------------------------------------------------------------------------
splsda.srbct <- splsda(X, Y, ncomp = ncomp, keepX = select.keepX) 

## ------------------------------------------------------------------------
plotIndiv(splsda.srbct, comp = c(1,2),
          group = srbct$class, ind.names = FALSE, 
          ellipse = TRUE, legend = TRUE,
          title = 'sPLS-DA on SRBCT, comp 1 & 2')

## ------------------------------------------------------------------------
plotIndiv(splsda.srbct, comp = c(1,3),
          group = srbct$class, ind.names = FALSE, 
          ellipse = TRUE, legend = TRUE,
          title = 'sPLS-DA on SRBCT, comp 1 & 3')

## ------------------------------------------------------------------------
plotLoadings(splsda.srbct, comp = 1, title = 'Loadings on comp 1', 
             contrib = 'max', method = 'mean')

## ------------------------------------------------------------------------
plotLoadings(splsda.srbct, comp = 2, title = 'Loadings on comp 2', 
             contrib = 'max', method = 'mean')

## ------------------------------------------------------------------------
plotLoadings(splsda.srbct, comp = 3, title = 'Loadings on comp 3', 
             contrib = 'max', method = 'mean')

## ------------------------------------------------------------------------
# if RStudio gives you trouble with window size, uncomment using the save argument
# cim(splsda.srbct, , save = 'jpeg', name.save = 'mycim')

# to visualise genes selected on comp 1 only
# cim(splsda.srbct, comp=1, title ="Component 1", save = 'jpeg', name.save = 'mycim-comp1')

## ------------------------------------------------------------------------
plotArrow(splsda.srbct, legend=T)

## ------------------------------------------------------------------------
sessionInfo()

## ---- include = FALSE----------------------------------------------------
# extract R code
#purl("PLSDA_SRBCT.Rmd")

